class Repurchase:
    def __init__(self, company, stock_symbol, repurchase_price, repurchase_quantity):
        self.company = company
        self.stock_symbol = stock_symbol
        self.repurchase_price = repurchase_price
        self.repurchase_quantity = repurchase_quantity
        self.total_cost = self.repurchase_price * self.repurchase_quantity
        self.method= None


#高管离职适合单独写一个类。离职是一个独立的事件，不属于高管的常规行为，因此它应该是一个单独的类。这样可以更好地隔离它，更方便维护代码和扩展功能。
class SeniorManagerDeparture:
    def __init__(self, name, reason_for_departure, notice_period, final_day):
        self.name = name
        self.reason_for_departure = reason_for_departure
        self.notice_period = notice_period
        self.final_day = final_day
        
    def announcement(self):
        announcement = f"We would like to inform you that {self.name}, a senior manager, has decided to resign for {self.reason_for_departure}. "
        announcement += f"Their notice period is {self.notice_period}"


from cpanlp.account.assets.financialasset.financialasset import *

class Bond(FinancialAsset):
    accounts = []
    def __init__(self, account, debit,date,parties, consideration, obligations,value, rate):
        super().__init__(account, debit,date,parties, consideration, obligations,value)
        self.rate = rate
        Bond.accounts.append(self)